@@ -4,12 +4,17 @@
 """lingualabpy"""
 from __future__ import annotations
 
-__version__ = "0.0.2"
+__version__ = "0.0.5"
 
 default_config = {
     "participant_col": "participant_id",
     "participant_label": "IE",
     "clinician_label": "IV",
+    "f0_bounds": {
+        "female": [100.0, 600.0],
+        "male": [75.0, 300.0],
+    },
+    "unit_frequency": "Hertz",
 }
 
 from lingualabpy.io import read_audio, read_docx, read_json, write_json, read_textgrid
