@@ -33,10 +33,17 @@ def read_json(json_path: str) -> Union[list, dict]:
 def write_json(data: Union[list, dict], json_path: str) -> None:
     """"""
     with open(json_path, "w") as file:
-        json.dump(data, file)
+        json.dump(data, file, indent=4)
 
 
 # .TextGrid files
 def read_textgrid(textgrid_path: str) -> TextGrid:
     """"""
-    return TextGrid(textgrid_path)
+    textgrid = TextGrid(textgrid_path)
+    # Cleaning of the interval text
+    for intervals in textgrid.values():
+        for interval in intervals:
+            interval.text = (
+                interval.text.encode().decode("unicode_escape").strip(" \n\r\t")
+            )
+    return textgrid
